@@ -3,10 +3,10 @@ Print out some information on specific GEO's data set.
 Does not download the data set.
 """
 
-from Orange.bio import obiGEO
+import Orange.bio.geo
 import textwrap
 
-gdsinfo = obiGEO.GDSInfo()
+gdsinfo = Orange.bio.geo.GDSInfo()
 gds = gdsinfo["GDS10"]
 
 print "ID:", gds["dataset_id"]
